@@ -1,3 +1,5 @@
+from .compat import is_py3, unicode
+
 class Symbol:
     """Abstract class"""
     def __init__(self, ticker, name, exchange):
@@ -11,5 +13,8 @@ class Symbol:
     def getRow(self):
         return [self.ticker, self.name, self.exchange]
 
-    def __str__(self):
-        return self.getType() + " " + self.ticker + " " + str(self.exchange) + " " + str(self.name)
+    def __unicode__(self):
+        return "" + self.getType() + " " + self.ticker + " " + unicode(self.exchange) + " " + unicode(self.name)
+
+if is_py3:
+    Symbol.__str__ = Symbol.__unicode__
